# BloraMc

BloraMc is a simple Python package for fun and easy message printing.  
It’s just the beginning — many useful features will be added soon!  

## Installation

You can install BloraMc using pip:

`pip install bloramc`
